@@ -1,5 +1,5 @@
 from salesforce_tools.salesforce import SalesforceAPI, SalesforceModelFactory, RestAPI, ToolingAPI
-from salesforce_tools.auth import login, SalesforceOAuthClient, SalesforceJWTClient
+from salesforce_tools.auth import login, SalesforceOAuthClient, SalesforceJWTClient, sfdx_auth_url_to_dict
 from salesforce_tools.bulk import BulkAPI, BulkJobException
 from salesforce_tools.bulk_models import JobInfo, JobInfoList, JobTypeEnum, JobStateEnum, OperationEnum, ContentTypeEnum
 from salesforce_tools.oauth_server import CallbackServer, OAuthCallbackHandler
